#include <Stepper.h>
#include <SoftModem.h>
#include <ctype.h>

#define DIR_PIN 2
#define STEP_PIN 9
#define SHUTTER_PIN 7

SoftModem modem;

boolean done = true;
int numRotations = 15;
char val;
int ledPin = 13;
int phonePin = 4;
float rotAmt = 240;
float motor_speed = 0.05;

void setup() { 
  pinMode(DIR_PIN, OUTPUT); 
  pinMode(STEP_PIN, OUTPUT); 
  pinMode(SHUTTER_PIN, OUTPUT);
  pinMode(ledPin, OUTPUT);
  pinMode(phonePin, INPUT);
  Serial.begin(9600);
  modem.begin();
} 

void loop(){

  if(Serial.available()){
    val = Serial.read();
    
    modem.write(val);
    // blink LED to show that signal was sent to iPhone
    digitalWrite(ledPin, HIGH);
    delay(100);
    digitalWrite(ledPin, LOW);
  }
  
  if(val=='L'){
    // move the motor cW one revolution
    digitalWrite(ledPin, HIGH);
    // move the motor
    rotateDeg(rotAmt, motor_speed);
    takePhoto(1);
    
  }else if(val=='R'){
    // move the motor CCW one revolution
    rotateDeg(-rotAmt, motor_speed);
    digitalWrite(ledPin, HIGH);
    takePhoto(1);
  }else if(val=='S'){
    // do an entire 360 spin
       for(int i = 0; i<numRotations; i++){
        digitalWrite(ledPin, HIGH);
        // move the motor
        
        rotateDeg(rotAmt, motor_speed);
        takePhoto(1);
      }
  }
  
  /*
    RECEIVED SIGNAL FROM IPHONE - START TURNTABLE
  */
  if(modem.available ()) {
    // receive from signal from iphone 
     int input = modem.read ();
     if(input == 255){
//       startSpin();
        rotateDeg(rotAmt, motor_speed);
     }     
   }
}

void startSpin(){
  for(int i = 0; i<numRotations; i++){
      digitalWrite(ledPin, HIGH);
      // move the motor
      rotateDeg(rotAmt, motor_speed);
      // take a photo
      takePhoto(i);
    }
}

void takePhoto(int rotation){
    // snap a photo
     modem.write(rotation*rotAmt);
     
    digitalWrite(SHUTTER_PIN, HIGH);
    delay(1000);
    digitalWrite(SHUTTER_PIN, LOW);
    digitalWrite(ledPin, LOW);
    delay(1000);
}


void rotate(int steps, float speed){ 
  //rotate a specific number of microsteps (8 microsteps per step) - (negitive for reverse movement)
  //speed is any number from .01 -> 1 with 1 being fastest - Slower is stronger
  int dir = (steps > 0)? HIGH:LOW;
  steps = abs(steps);

  digitalWrite(DIR_PIN,dir); 

  float usDelay = (1/speed) * 70;

  for(int i=0; i < steps; i++){ 
    digitalWrite(STEP_PIN, HIGH); 
    delayMicroseconds(usDelay); 

    digitalWrite(STEP_PIN, LOW); 
    delayMicroseconds(usDelay); 
  } 
} 

void rotateDeg(float deg, float speed){ 
  //rotate a specific number of degrees (negitive for reverse movement)
  //speed is any number from .01 -> 1 with 1 being fastest - Slower is stronger
  int dir = (deg > 0)? HIGH:LOW;
  digitalWrite(DIR_PIN,dir); 

  int steps = abs(deg)*(1/0.225);
  float usDelay = (1/speed) * 70;

  for(int i=0; i < steps; i++){ 
    digitalWrite(STEP_PIN, HIGH); 
    delayMicroseconds(usDelay); 

    digitalWrite(STEP_PIN, LOW); 
    delayMicroseconds(usDelay); 
  } 
}
